Example: Approximate nearest neighbor search — scikit-hubness 0.21.0 documentation

# Example: Approximate nearest neighbor search

This example shows how to perform approximate nearest neighbor search.

Retrieving GLOVE word vectors

`Download all examples in Python source code: auto_examples_ann_python.zip`

`Download all examples in Jupyter notebooks: auto_examples_ann_jupyter.zip`

Gallery generated by Sphinx-Gallery

©2019, Roman Feldbauer. | Powered by Sphinx 2.1.2 & Alabaster 0.7.12 | Page source